@@ -29,7 +29,7 @@ except ImportError:
     pep8 = None
 
 
-__version__ = '0.5'
+__version__ = '0.5.1'
 
 
 pep8bin = 'pep8'
@@ -473,6 +473,45 @@ class FixPEP8(object):
                 modified_lines.append(i)
             line = self.source[line_index]
 
+        # Skip cases with multiple arguments as to not handle tracebacks
+        # incorrectly in cases such as "raise Exception, Value, Traceback".
+        if line.count(',') - line.count(',)') > 1:
+            # TODO: Don't Care corner cases.
+            import ast
+            indent = (self._get_indentlevel(line) - 1) * self.indent_word
+            indent_offset = (self._get_indentlevel(line) - 1) * \
+                    len(self.indent_word)
+            ast_body = ast.parse(line[indent_offset:]).body[0]
+            _id = [indent, ]
+            for node in ast.iter_child_nodes(ast_body):
+                if ast.Str == type(node):
+                    quote_word = line[node.col_offset]
+                    if quote_word * 3 == \
+                            line[node.col_offset:node.col_offset + 3]:
+                        quote_word = quote_word * 3
+                    _id.append(quote_word + node.s + quote_word)
+                    continue
+                if ast.Name == type(node):
+                    _id.append(node.id)
+                    continue
+                _id.append(repr(ast.literal_eval(node)))
+            # find space and comment
+            sio = StringIO(line)
+            old_tokens = None
+            for tokens in tokenize.generate_tokens(sio.readline):
+                if tokens[0] is tokenize.COMMENT:
+                    comment_offset = old_tokens[3][1]
+                    _id.append(line[comment_offset:])
+                    break
+                elif len(_id) == 4 and tokens[0] is token.NEWLINE:
+                    _id.append(self.newline)
+                    break
+                old_tokens = tokens
+            # create to fixed source
+            self.source[result['line'] - 1] = "%sraise %s(%s), None, %s%s" % (
+                    tuple(_id))
+            return modified_lines
+
         sio = StringIO(line)
         is_found_raise = False
         first_comma_found = False
@@ -536,9 +575,9 @@ def _find_newline(source):
         if CRLF in s:
             crlf += 1
         elif CR in s:
-            cr += 0
+            cr += 1
         elif LF in s:
-            lf += 0
+            lf += 1
     _max = max(cr, crlf, lf)
     if _max == lf:
         return LF
@@ -646,4 +685,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
