@@ -2,6 +2,30 @@ import os
 import unittest
 from subprocess import Popen, PIPE
 from tempfile import mkstemp
+import autopep8
+
+
+class TestUtils(unittest.TestCase):
+
+    def test_find_newline_only_cr(self):
+        source = ["print 1\r", "print 2\r", "print3\r"]
+        self.assertEqual(autopep8.CR, autopep8._find_newline(source))
+
+    def test_find_newline_only_lf(self):
+        source = ["print 1\n", "print 2\n", "print3\n"]
+        self.assertEqual(autopep8.LF, autopep8._find_newline(source))
+
+    def test_find_newline_only_crlf(self):
+        source = ["print 1\r\n", "print 2\r\n", "print3\r\n"]
+        self.assertEqual(autopep8.CRLF, autopep8._find_newline(source))
+
+    def test_find_newline_cr1_and_lf2(self):
+        source = ["print 1\n", "print 2\r", "print3\n"]
+        self.assertEqual(autopep8.LF, autopep8._find_newline(source))
+
+    def test_find_newline_cr1_and_crlf2(self):
+        source = ["print 1\r\n", "print 2\r", "print3\r\n"]
+        self.assertEqual(autopep8.CRLF, autopep8._find_newline(source))
 
 
 class TestFixPEP8Error(unittest.TestCase):
@@ -216,7 +240,7 @@ while True:
         self.assertEqual(self.result, fixed)
 
 
-class TestFixPEP8Warn(unittest.TestCase):
+class TestFixPEP8Warning(unittest.TestCase):
 
     def setUp(self):
         self.tempfile = mkstemp()
@@ -329,11 +353,10 @@ class TestFixPEP8Warn(unittest.TestCase):
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
-    def test_w602_arg_is_tuple(self):
-        line = "raise ValueError, ('a', 'b')\n"
-        fixed = "raise ValueError('a', 'b')\n"
+    def test_w602_skip_ambiguous_case(self):
+        line = "raise 'a', 'b', 'c'\n"
         self._inner_setup(line)
-        self.assertEqual(self.result, fixed)
+        self.assertEqual(self.result, line)
 
     def test_w602_triple_quotes(self):
         line = 'raise ValueError, """hello"""\n1\n'
@@ -425,6 +448,18 @@ class TestFixPEP8Warn(unittest.TestCase):
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    def test_w602_raise_argument_triple(self):
+        line = 'raise ValueError, "info", traceback\n'
+        fixed = 'raise ValueError("info"), None, traceback\n'
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
+    def test_w602_raise_argument_triple_with_comment(self):
+        line = 'raise ValueError, "info", traceback  # comment\n'
+        fixed = 'raise ValueError("info"), None, traceback  # comment\n'
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
     def test_w603(self):
         line = "if 2 <> 2:\n    print False"
         fixed = "if 2 != 2:\n    print False\n"
